@@ -3,29 +3,33 @@
 #****************************************************************************
 # spellcheck.py, provides a class for a interface to aspell or ispell
 #
-# Copyright (C) 2004, Douglas W. Bell
+# Copyright (C) 2006, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
-# terms of the GNU General Public License, Version 2.  This program is
-# distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
+# terms of the GNU General Public License, either Version 2 or any later
+# version.  This program is distributed in the hope that it will be useful,
+# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
 #*****************************************************************************
 
-import os.path, re, sys
+import os.path
+import re
+import sys
 
-class SpellCheck:
+class SpellCheck(object):
     """Interfaces with aspell or ispell and stores session hooks"""
     def __init__(self, spellPath='', langCode=''):
         """Create initial hooks to outside program"""
-        aspellOpts = '-a -H --encoding=utf-8'
+        aspellOpts = ['-a -H --encoding=utf-8']
+        ispellOpts = ['-a -h -Tutf8', '-a']
         if langCode:
-            aspellOpts = '%s --lang=%s' % (aspellOpts, langCode)
+            aspellOpts.insert(0, '%s --lang=%s' % (aspellOpts[0], langCode))
         if not spellPath:
-            cmdList = ('aspell %s' % aspellOpts, \
-                       'ispell -a -h -Tutf8', 'ispell -a')
+            cmdList = ['aspell %s' % opt for opt in aspellOpts]
+            cmdList.extend(['ispell %s' % opt for opt in ispellOpts])
         elif spellPath.find('aspell') >= 0:
-            cmdList = ('%s %s' % (spellPath, aspellOpts),)
+            cmdList = ['%s %s' % (spellPath, opt) for opt in aspellOpts]
         else:
-            cmdList = ('%s -a -h -Tutf8' % spellPath, '%s -a' % spellPath)
+            cmdList = ['%s %s' % (spellPath, opt) for opt in ispellOpts]
         for cmd in cmdList:
             try:
                 self.stdIn, self.stdOut, err = os.popen3(cmd)
@@ -37,16 +41,18 @@ class SpellCheck:
                 pass
         raise SpellCheckError('Could not init aspell or ispell')
  
-    def checkLine(self, line, skipList=[]):
+    def checkLine(self, line, skipList=None):
         """Check one (and only one!) line of text, ignore words in skipList,
            return a list of tuples, each with the mispelled word, position in
            the line, and a list of suggestions"""
+        if not skipList:
+            skipList = []
         self.stdIn.write('^%s\n' % line.encode('utf-8'))
         self.stdIn.flush()
         results = [self.stdOut.readline()]
         while results[-1] != '\n':
             results.append(self.stdOut.readline())
-        return filter(None, [formatOutput(unicode(line, 'utf-8'), skipList) \
+        return filter(None, [formatOutput(unicode(line, 'utf-8'), skipList)
                              for line in results])
 
     def close(self):
@@ -84,7 +90,7 @@ def formatOutput(line, skipList=[]):
     if guessMatch:
         word = guessMatch.group(1)
         if word not in skipList:
-            return (word, int(guessMatch.group(2)) - 1, \
+            return (word, int(guessMatch.group(2)) - 1,
                     guessMatch.group(3).split(', '))
         else:
             return None
