@@ -35,16 +35,17 @@ class TreeItem(object):
     blankTitle = _('[BLANK TITLE]')
     maxLevel = 0  # for ODF export
     dirExportLinkRe = re.compile(r'<a href="#(.+)">')
+    dirExportDirRe = re.compile(r'[/\\"*?|<>:]')
     def __init__(self, parent, formatName, initText='', addDefaultData=False):
         self.parent = parent
         self.formatName = formatName
         self.data = {}
+        self.childList = []
         if initText:
             self.setTitle(initText)
         if addDefaultData:
             self.nodeFormat().setInitDefaultData(self.data)
         self.open = False
-        self.childList = []
         self.viewData = None
         self.level = 0    # updated only by numbered descend list
 
@@ -305,7 +306,7 @@ class TreeItem(object):
             dirName = ''
         if encode:
             dirName = dirName.encode(sys.getfilesystemencoding(), 'replace')
-        dirName = dirName.strip('/\\"*?|<>:')
+        dirName = TreeItem.dirExportDirRe.sub('', dirName)
         if not dirName:
             dirName = '___'
         return dirName
@@ -634,7 +635,7 @@ class TreeItem(object):
             newFormat = self.childList and self.childList[0].formatName or \
                         self.formatName
         newItem = TreeItem(self, newFormat, text, True)
-        newItem.setUniqueID()
+        newItem.setUniqueID(True)
         self.childList.insert(pos, newItem)
         globalref.docRef.modified = True
         return newItem
@@ -650,7 +651,7 @@ class TreeItem(object):
         if newFormat not in globalref.docRef.treeFormats:
             newFormat = self.formatName
         newItem = TreeItem(self.parent, newFormat, text, True)
-        newItem.setUniqueID()
+        newItem.setUniqueID(True)
         self.parent.childList.insert(pos, newItem)
         globalref.docRef.modified = True
         return newItem
@@ -919,7 +920,7 @@ class TreeItem(object):
             newParent = child.findEquivFields(catList, newItems)
             if not newParent:
                 newParent = TreeItem(self, newType)
-                newParent.setUniqueID()
+                newParent.setUniqueID(True)
                 for field in catList:
                     newParent.data[field] = child.data.get(field, '')
                 newItems.append(newParent)
